@@ -3,6 +3,7 @@
 #' This function create a heading text
 #' @param text_input Text to display
 #' @param size Text size using xl, l, m, s.  Defaults to xl.
+#' @param id Custom header id
 #' @return a heading text html shiny object
 #' @keywords heading
 #' @export
@@ -23,8 +24,14 @@
 #'   shinyApp(ui = ui, server = server)
 #' }
 
-heading_text <- function(text_input, size = "xl"){
+heading_text <- function(text_input, size = "xl", id){
+
+   if(missing(id)){
+     id <- clean_heading_text(text_input)
+   }
+
   govHeading <- shiny::tags$h1(shiny::HTML(text_input),
-                               class=paste0("govuk-heading-", size))
+                               class=paste0("govuk-heading-", size),
+                               id = id)
   attachDependency(govHeading)
 }
