@@ -17,7 +17,13 @@ test_that("text area works", {
 
 test_that("text area error works", {
 
-  text_area_check <- text_area_Input("input1", "Test area", error = TRUE, error_message = "Test error", row_no = 10)
+  text_area_check <- text_area_Input(
+    "input1",
+    "Test area",
+    error = TRUE,
+    error_message = "Test error",
+    row_no = 10
+  )
 
   expect_equal(
     text_area_check$children[[4]]$attribs$rows,
@@ -42,7 +48,10 @@ test_that("text area word works", {
   text_area_check <- text_area_Input("input1", "Test area", word_limit = 300)
 
   expect_identical(
-    text_area_check$children[[5]]$children[[1]],
+    paste(text_area_check$children[[5]]$children[[1]]$children[[1]],
+          text_area_check$children[[5]]$children[[2]]$children[[1]],
+          text_area_check$children[[5]]$children[[3]]$children[[1]]
+          ),
     "You have used 0 of the 300 allowed"
   )
 
